///////////////////////////////////////////////////////////////////////////////
//
// Declaration file for the special functions library
//
// Written by Marc Paterno
//
//

#include <cmath>

#ifndef _SPECFUNC_HPP_
#define _SPECFUNC_HPP_

// natural logarithm of gamma function
double gammln(double x);

// natural logarithm of factorial function
double factln(unsigned long n);


// complete beta function
double beta(double z, double w);

// continuing fraction solution for the beta function
double betacf(double a, double b , double x);

// incomplete beta function
double betai(double a, double b, double x);

// incomplete beta function divided by complete beta function
double ibetai(double a, double b, double x);

// gamma function
inline double gamma(double x) 
{
  return std::exp(gammln(x));
} 

// factorial function
inline double factorial(unsigned long n) {
  return std::exp(factln(n));
}

#endif // _SPECFUNC_HPP_
